@@ -1,4 +1,7 @@
 # Copyright (C) 2009-2020 Andrea Francia Trivolzio(PV) Italy
+import os.path
+
+
 def main():
     for mp in os_mount_points():
         print(mp)
@@ -6,8 +9,9 @@ def main():
 
 def os_mount_points():
     import psutil
-    for p in psutil.disk_partitions(all = True):
-        yield p.mountpoint
+    for p in psutil.disk_partitions():
+        if os.path.isdir(p.mountpoint):
+            yield p.mountpoint
 
 
 if __name__ == "__main__":
